# AquaCrop-OS
> Python version of AquaCropOS


```python
#hide
```

This file will become your README and also the index of your documentation.

## Install

`pip install aquacrop`

## How to use

import aquacrop and run

# to do:

 - Adjust dz so that it covers whole root zone. [0.1]*12 if max root <1.2m otherwise add more depth to final layers.
